@@ -86,35 +86,10 @@ write.xport <- function(...,
     #######
 
 
-    #######
-    ##
-    scat("Check length of object names...\n")
-    long.names <- which(nchar(dfNames)>8)
-    if(length(long.names)>0)
-      {
-        old.names <- dfNames[long.names]
-        new.names <- substr(old.names, 1, 8 )
-        
-        warning("Truncating object names with more than 8 characters. ",
-                paste(long.names,
-                      ":'",
-                      old.names,
-                      "' --> '",
-                      new.names,
-                      "'",
-                      sep="",
-                      collapse=", " ))
-        
-        dfNames[long.names] <- new.names
-      }
-
     #######
     ##
     scat("Ensure object names are valid and unique...\n")
-    dfNames <- substr(make.names(dfNames, unique=TRUE),1,8)
-    if( all(names(dfList)!=dfNames))
-      warning("Data frame names modified to obey SAS rules")
-    names(dfList) <- dfNames
+    names(dfList) <- dfNames <- makeSASNames(dfNames)
     ##
     #######
 
@@ -148,8 +123,8 @@ write.xport <- function(...,
     if(file==stdout())
       out <- function(...)
         {
-          cat("ASCII: ", rawToDisplay(...), "")
-          cat("HEX:   ", ..., "")
+          cat("ASCII: ", rawToDisplay(...), "\n")
+          cat("HEX:   ", ..., "\n")
         }
     else
       out <- function(...) writeBin( ..., raw(), con=file)
@@ -174,22 +149,21 @@ write.xport <- function(...,
             dfList[[i]] <- df
           }
 
-        varNames <- substr(make.names(colnames(df), unique=TRUE),1,8)
-        if( any(colnames(df)!=varNames))
-          {
-            warning("Variable names modified to obey SAS rules")
-            colnames(df) <- varNames
-            dfList[[i]] <- df
-          }
-
+        
+        colnames(dfList[[i]]) <- colnames(df) <- varNames <- makeSASNames(colnames(df))
+        
         offsetTable <- data.frame("name"=varNames, "len"=NA, "offset"=NA )
         rownames(offsetTable) <- offsetTable[,"name"]
 
+        dfLabel <- label(df, default="" )
+        dfType <- SAStype(df, default="")
+        
         scat("Write data frame header ...")
-        out( xport.member.header(dfName=i, cDate=cDate, sasVer=sasVer, osType=osType ) )
+        out( xport.member.header(dfName=i, cDate=cDate, sasVer=sasVer, osType=osType,
+                                 dfLabel=dfLabel, dfType=dfType) )
         scat("Done.")
 
-        scat("Write variable informaton block header ...")
+        scat("Write variable information block header ...")
         out( xport.namestr.header( nvar=ncol(df) ) )
         scat("Done.")
         
